@@ -2,6 +2,7 @@ import logging
 
 from erdpy import wallet
 from erdpy.accounts import Account, Address
+from erdpy.blockatlas import BlockAtlas
 from erdpy.contracts import CodeMetadata, SmartContract
 from erdpy.environments import TestnetEnvironment
 from erdpy.projects import load_project
@@ -110,8 +111,9 @@ def query_smart_contract(args):
     environment.run_flow(flow)
 
 
-def get_account_nonce(proxy_url, address):
-    logger.debug("call_get_account_nonce")
+def get_account_nonce(args):
+    proxy_url = args.proxy
+    address = args.address
 
     proxy = ElrondProxy(proxy_url)
     nonce = proxy.get_account_nonce(Address(address))
@@ -119,8 +121,9 @@ def get_account_nonce(proxy_url, address):
     return nonce
 
 
-def get_account_balance(proxy_url, address):
-    logger.debug("call_get_account_balance")
+def get_account_balance(args):
+    proxy_url = args.proxy
+    address = args.address
 
     proxy = ElrondProxy(proxy_url)
     balance = proxy.get_account_balance(Address(address))
@@ -128,8 +131,9 @@ def get_account_balance(proxy_url, address):
     return balance
 
 
-def get_account(proxy_url, address):
-    logger.debug("call_get_account")
+def get_account(args):
+    proxy_url = args.proxy
+    address = args.address
 
     proxy = ElrondProxy(proxy_url)
     account = proxy.get_account(Address(address))
@@ -137,42 +141,63 @@ def get_account(proxy_url, address):
     return account
 
 
-def get_num_shards(proxy_url):
-    logger.debug("call_get_number_of_shards")
+def get_account_transactions(args):
+    proxy_url = args.proxy
+    address = args.address
 
+    proxy = ElrondProxy(proxy_url)
+    account = proxy.get_account_transactions(Address(address))
+    print(account)
+    return account
+
+
+def get_num_shards(args):
+    proxy_url = args.proxy
     proxy = ElrondProxy(proxy_url)
     num_shards = proxy.get_num_shards()
     print(num_shards)
     return num_shards
 
 
-def get_last_block_nonce(proxy_url, shard_id):
-    logger.debug("call_get_last_block_nonce")
-
+def get_last_block_nonce(args):
+    proxy_url = args.proxy
+    shard_id = args.shard_id
     proxy = ElrondProxy(proxy_url)
     nonce = proxy.get_last_block_nonce(shard_id)
     print(nonce)
     return nonce
 
 
-def get_gas_price(proxy_url):
-    logger.debug("call_get_gas_price")
-
+def get_gas_price(args):
+    proxy_url = args.proxy
     proxy = ElrondProxy(proxy_url)
     price = proxy.get_gas_price()
     print(price)
     return price
 
 
-def get_chain_id(proxy_url):
-    logger.debug("call_get_chain_id")
-
+def get_chain_id(args):
+    proxy_url = args.proxy
     proxy = ElrondProxy(proxy_url)
     chain_id = proxy.get_chain_id()
     print(chain_id)
     return chain_id
 
 
+def get_meta_nonce(args):
+    proxy = ElrondProxy(args.proxy)
+    nonce = proxy.get_meta_nonce()
+    print(nonce)
+    return nonce
+
+
+def get_meta_block(args):
+    proxy = ElrondProxy(args.proxy)
+    block = proxy.get_meta_block(args.nonce)
+    print(block)
+    return block
+
+
 def get_transaction_cost(args):
     logger.debug("call_get_transaction_cost")
 
@@ -229,6 +254,11 @@ def prepare_and_send_change_reward_address_transaction(args):
     return prepare_and_send_transaction(args)
 
 
+def prepare_and_send_claim_transaction(args):
+    args = validators.parse_args_for_claim(args)
+    return prepare_and_send_transaction(args)
+
+
 def generate_pem(args):
     pem_file = args.pem
 
@@ -246,3 +276,24 @@ def do_bech32(args):
     result = address.bech32() if encode else address.hex()
     print(result)
     return result
+
+
+def blockatlas_get_current_block_number(args):
+    client = BlockAtlas(args.url, args.coin)
+    number = client.get_current_block_number()
+    print(number)
+    return number
+
+
+def blockatlas_get_block_by_number(args):
+    client = BlockAtlas(args.url, args.coin)
+    block = client.get_block_by_number(args.number)
+    print(block)
+    return block
+
+
+def blockatlas_get_txs_by_address(args):
+    client = BlockAtlas(args.url, args.coin)
+    transactions = client.get_txs_by_address(args.address)
+    print(transactions)
+    return transactions
